pub struct AccountParser;Trait Implementations
Sourceimpl Clone for AccountParser
impl Clone for AccountParser
Sourcefn clone(&self) -> AccountParser
fn clone(&self) -> AccountParser
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccountParser
impl Debug for AccountParser
Sourceimpl Parser for AccountParser
impl Parser for AccountParser
Sourcetype Input = SubscribeUpdateAccount
type Input = SubscribeUpdateAccount
The input update type for this parser.
Sourcetype Output = ShieldProgramState
type Output = ShieldProgramState
The type of the parsed value produced by this parser.
Sourcefn id(&self) -> Cow<'_, str>
fn id(&self) -> Cow<'_, str>
A unique ID for this parser. Used to associate the parser with its
requested prefilter data. Read more
Sourcefn prefilter(&self) -> Prefilter
fn prefilter(&self) -> Prefilter
Filter data passed to Yellowstone to coarsely narrow down updates
to values parseable by this parser.
Sourceasync fn parse(&self, acct: &AccountUpdate) -> ParseResult<Self::Output>
async fn parse(&self, acct: &AccountUpdate) -> ParseResult<Self::Output>
Parse the given update into a parsed value.
Sourceimpl ProgramParser for AccountParser
impl ProgramParser for AccountParser
Sourcefn program_id(&self) -> Pubkey
fn program_id(&self) -> Pubkey
The program ID that this parser is associated with.
impl Copy for AccountParser