pub struct InstructionParser;Trait Implementations
Sourceimpl Clone for InstructionParser
impl Clone for InstructionParser
Sourcefn clone(&self) -> InstructionParser
fn clone(&self) -> InstructionParser
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstructionParser
impl Debug for InstructionParser
Sourceimpl Parser for InstructionParser
impl Parser for InstructionParser
Sourcetype Input = InstructionUpdate
type Input = InstructionUpdate
The input update type for this parser.
Sourcetype Output = ShieldProgramIx
type Output = ShieldProgramIx
The type of the parsed value produced by this parser.
Sourcefn id(&self) -> Cow<'_, str>
fn id(&self) -> Cow<'_, str>
A unique ID for this parser. Used to associate the parser with its
requested prefilter data. Read more
Sourcefn prefilter(&self) -> Prefilter
fn prefilter(&self) -> Prefilter
Filter data passed to Yellowstone to coarsely narrow down updates
to values parseable by this parser.
Sourceasync fn parse(
&self,
ix_update: &InstructionUpdate,
) -> ParseResult<Self::Output>
async fn parse( &self, ix_update: &InstructionUpdate, ) -> ParseResult<Self::Output>
Parse the given update into a parsed value.
Sourceimpl ProgramParser for InstructionParser
impl ProgramParser for InstructionParser
Sourcefn program_id(&self) -> Pubkey
fn program_id(&self) -> Pubkey
The program ID that this parser is associated with.
impl Copy for InstructionParser